/*
 * Internal module API header file.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtNetworkAuth.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#ifndef _QtNetworkAuthAPI_H
#define _QtNetworkAuthAPI_H

#if !defined(Py_LIMITED_API)
#define Py_LIMITED_API
#endif

#include "sip.h"

#include <QMetaType>
#include <QThread>

/* These are the qualifiers that are enabled. */
#define SIP_FEATURE_PyQt_CONSTEXPR
#define SIP_FEATURE_PyQt_MacOSXOnly
#define SIP_FEATURE_PyQt_Process
#define SIP_FEATURE_PyQt_NotBootstrapped
#define SIP_FEATURE_PyQt_Desktop_OpenGL
#define SIP_FEATURE_PyQt_OpenGL
#define SIP_FEATURE_PyQt_RawFont
#define SIP_FEATURE_PyQt_PrintPreviewDialog
#define SIP_FEATURE_PyQt_PrintPreviewWidget
#define SIP_FEATURE_PyQt_Printer
#define SIP_FEATURE_PyQt_PrintDialog
#define SIP_FEATURE_Py_v3
#define SIP_FEATURE_PyQt_qreal_double
#define SIP_FEATURE_PyQt_SSL
#define SIP_FEATURE_PyQt_SessionManager
#define SIP_FEATURE_PyQt_Accessibility
#define SIP_PLATFORM_WS_X11


/*
 * Convenient names to refer to various strings defined in this module.
 * Only the class names are part of the public API.
 */
#define sipNameNr_QOAuth1Signature__HttpRequestMethod 0
#define sipName_QOAuth1Signature__HttpRequestMethod &sipStrings_QtNetworkAuth[0]
#define sipNameNr_clientIdentifierSharedKeyChanged 36
#define sipName_clientIdentifierSharedKeyChanged &sipStrings_QtNetworkAuth[36]
#define sipNameNr_RequestingTemporaryCredentials 69
#define sipName_RequestingTemporaryCredentials &sipStrings_QtNetworkAuth[69]
#define sipNameNr_temporaryCredentialsUrlChanged 100
#define sipName_temporaryCredentialsUrlChanged &sipStrings_QtNetworkAuth[100]
#define sipNameNr_OAuthTokenSecretNotFoundError 131
#define sipName_OAuthTokenSecretNotFoundError &sipStrings_QtNetworkAuth[131]
#define sipNameNr_authorizationCallbackReceived 161
#define sipName_authorizationCallbackReceived &sipStrings_QtNetworkAuth[161]
#define sipNameNr_QOAuth2AuthorizationCodeFlow 191
#define sipName_QOAuth2AuthorizationCodeFlow &sipStrings_QtNetworkAuth[191]
#define sipNameNr_QOAuthHttpServerReplyHandler 220
#define sipName_QOAuthHttpServerReplyHandler &sipStrings_QtNetworkAuth[220]
#define sipNameNr_TemporaryCredentialsReceived 249
#define sipName_TemporaryCredentialsReceived &sipStrings_QtNetworkAuth[249]
#define sipNameNr_setClientIdentifierSharedKey 278
#define sipName_setClientIdentifierSharedKey &sipStrings_QtNetworkAuth[278]
#define sipNameNr_QAbstractOAuth__ContentType 307
#define sipName_QAbstractOAuth__ContentType &sipStrings_QtNetworkAuth[307]
#define sipNameNr_generateAuthorizationHeader 335
#define sipName_generateAuthorizationHeader &sipStrings_QtNetworkAuth[335]
#define sipNameNr_requestTemporaryCredentials 363
#define sipName_requestTemporaryCredentials &sipStrings_QtNetworkAuth[363]
#define sipNameNr_setModifyParametersFunction 391
#define sipName_setModifyParametersFunction &sipStrings_QtNetworkAuth[391]
#define sipNameNr_QAbstractOAuthReplyHandler 419
#define sipName_QAbstractOAuthReplyHandler &sipStrings_QtNetworkAuth[419]
#define sipNameNr_resourceOwnerAuthorization 446
#define sipName_resourceOwnerAuthorization &sipStrings_QtNetworkAuth[446]
#define sipNameNr_setTemporaryCredentialsUrl 473
#define sipName_setTemporaryCredentialsUrl &sipStrings_QtNetworkAuth[473]
#define sipNameNr_tokenCredentialsUrlChanged 500
#define sipName_tokenCredentialsUrlChanged &sipStrings_QtNetworkAuth[500]
#define sipNameNr_clientIdentifierSharedKey 527
#define sipName_clientIdentifierSharedKey &sipStrings_QtNetworkAuth[527]
#define sipNameNr_clientSharedSecretChanged 553
#define sipName_clientSharedSecretChanged &sipStrings_QtNetworkAuth[553]
#define sipNameNr_continueGrantWithVerifier 579
#define sipName_continueGrantWithVerifier &sipStrings_QtNetworkAuth[579]
#define sipNameNr_OAuthCallbackNotVerified 605
#define sipName_OAuthCallbackNotVerified &sipStrings_QtNetworkAuth[605]
#define sipNameNr_QOAuth1__SignatureMethod 630
#define sipName_QOAuth1__SignatureMethod &sipStrings_QtNetworkAuth[630]
#define sipNameNr_modifyParametersFunction 655
#define sipName_modifyParametersFunction &sipStrings_QtNetworkAuth[655]
#define sipNameNr_OAuthTokenNotFoundError 680
#define sipName_OAuthTokenNotFoundError &sipStrings_QtNetworkAuth[680]
#define sipNameNr_RequestingAuthorization 704
#define sipName_RequestingAuthorization &sipStrings_QtNetworkAuth[704]
#define sipNameNr_authorizationUrlChanged 728
#define sipName_authorizationUrlChanged &sipStrings_QtNetworkAuth[728]
#define sipNameNr_clientIdentifierChanged 752
#define sipName_clientIdentifierChanged &sipStrings_QtNetworkAuth[752]
#define sipNameNr_requestTokenCredentials 776
#define sipName_requestTokenCredentials &sipStrings_QtNetworkAuth[776]
#define sipNameNr_setNetworkAccessManager 800
#define sipName_setNetworkAccessManager &sipStrings_QtNetworkAuth[800]
#define sipNameNr_temporaryCredentialsUrl 824
#define sipName_temporaryCredentialsUrl &sipStrings_QtNetworkAuth[824]
#define sipNameNr_QAbstractOAuth__Status 848
#define sipName_QAbstractOAuth__Status &sipStrings_QtNetworkAuth[848]
#define sipNameNr_871 871
#define sipName_871 &sipStrings_QtNetworkAuth[871]
#define sipNameNr_createAuthenticatedUrl 894
#define sipName_createAuthenticatedUrl &sipStrings_QtNetworkAuth[894]
#define sipNameNr_setTokenCredentialsUrl 917
#define sipName_setTokenCredentialsUrl &sipStrings_QtNetworkAuth[917]
#define sipNameNr_signatureMethodChanged 940
#define sipName_signatureMethodChanged &sipStrings_QtNetworkAuth[940]
#define sipNameNr_QAbstractOAuth__Error 963
#define sipName_QAbstractOAuth__Error &sipStrings_QtNetworkAuth[963]
#define sipNameNr_QAbstractOAuth__Stage 985
#define sipName_QAbstractOAuth__Stage &sipStrings_QtNetworkAuth[985]
#define sipNameNr_QOAuthOobReplyHandler 1007
#define sipName_QOAuthOobReplyHandler &sipStrings_QtNetworkAuth[1007]
#define sipNameNr_RefreshingAccessToken 1029
#define sipName_RefreshingAccessToken &sipStrings_QtNetworkAuth[1029]
#define sipNameNr_RequestingAccessToken 1051
#define sipName_RequestingAccessToken &sipStrings_QtNetworkAuth[1051]
#define sipNameNr_accessTokenUrlChanged 1073
#define sipName_accessTokenUrlChanged &sipStrings_QtNetworkAuth[1073]
#define sipNameNr_setClientSharedSecret 1095
#define sipName_setClientSharedSecret &sipStrings_QtNetworkAuth[1095]
#define sipNameNr_setCustomMethodString 1117
#define sipName_setCustomMethodString &sipStrings_QtNetworkAuth[1117]
#define sipNameNr_authorizeWithBrowser 1139
#define sipName_authorizeWithBrowser &sipStrings_QtNetworkAuth[1139]
#define sipNameNr_buildAuthenticateUrl 1160
#define sipName_buildAuthenticateUrl &sipStrings_QtNetworkAuth[1160]
#define sipNameNr_callbackDataReceived 1181
#define sipName_callbackDataReceived &sipStrings_QtNetworkAuth[1181]
#define sipNameNr_generateRandomString 1202
#define sipName_generateRandomString &sipStrings_QtNetworkAuth[1202]
#define sipNameNr_networkAccessManager 1223
#define sipName_networkAccessManager &sipStrings_QtNetworkAuth[1223]
#define sipNameNr_networkReplyFinished 1244
#define sipName_networkReplyFinished &sipStrings_QtNetworkAuth[1244]
#define sipNameNr_setClientCredentials 1265
#define sipName_setClientCredentials &sipStrings_QtNetworkAuth[1265]
#define sipNameNr_setHttpRequestMethod 1286
#define sipName_setHttpRequestMethod &sipStrings_QtNetworkAuth[1286]
#define sipNameNr_PyQt5_QtNetworkAuth 1307
#define sipName_PyQt5_QtNetworkAuth &sipStrings_QtNetworkAuth[1307]
#define sipNameNr_expirationAtChanged 1327
#define sipName_expirationAtChanged &sipStrings_QtNetworkAuth[1327]
#define sipNameNr_refreshTokenChanged 1347
#define sipName_refreshTokenChanged &sipStrings_QtNetworkAuth[1347]
#define sipNameNr_responseTypeChanged 1367
#define sipName_responseTypeChanged &sipStrings_QtNetworkAuth[1367]
#define sipNameNr_setAuthorizationUrl 1387
#define sipName_setAuthorizationUrl &sipStrings_QtNetworkAuth[1387]
#define sipNameNr_setClientIdentifier 1407
#define sipName_setClientIdentifier &sipStrings_QtNetworkAuth[1407]
#define sipNameNr_setTokenCredentials 1427
#define sipName_setTokenCredentials &sipStrings_QtNetworkAuth[1427]
#define sipNameNr_tokenCredentialsUrl 1447
#define sipName_tokenCredentialsUrl &sipStrings_QtNetworkAuth[1447]
#define sipNameNr_clientSharedSecret 1467
#define sipName_clientSharedSecret &sipStrings_QtNetworkAuth[1467]
#define sipNameNr_contentTypeChanged 1486
#define sipName_contentTypeChanged &sipStrings_QtNetworkAuth[1486]
#define sipNameNr_customMethodString 1505
#define sipName_customMethodString &sipStrings_QtNetworkAuth[1505]
#define sipNameNr_extraTokensChanged 1524
#define sipName_extraTokensChanged &sipStrings_QtNetworkAuth[1524]
#define sipNameNr_refreshAccessToken 1543
#define sipName_refreshAccessToken &sipStrings_QtNetworkAuth[1543]
#define sipNameNr_requestAccessToken 1562
#define sipName_requestAccessToken &sipStrings_QtNetworkAuth[1562]
#define sipNameNr_setClientSharedKey 1581
#define sipName_setClientSharedKey &sipStrings_QtNetworkAuth[1581]
#define sipNameNr_setSignatureMethod 1600
#define sipName_setSignatureMethod &sipStrings_QtNetworkAuth[1600]
#define sipNameNr_tokenSecretChanged 1619
#define sipName_tokenSecretChanged &sipStrings_QtNetworkAuth[1619]
#define sipNameNr_HttpRequestMethod 18
#define sipName_HttpRequestMethod &sipStrings_QtNetworkAuth[18]
#define sipNameNr_WwwFormUrlEncoded 1638
#define sipName_WwwFormUrlEncoded &sipStrings_QtNetworkAuth[1638]
#define sipNameNr_clientCredentials 1656
#define sipName_clientCredentials &sipStrings_QtNetworkAuth[1656]
#define sipNameNr_httpRequestMethod 1674
#define sipName_httpRequestMethod &sipStrings_QtNetworkAuth[1674]
#define sipNameNr_replyDataReceived 1692
#define sipName_replyDataReceived &sipStrings_QtNetworkAuth[1692]
#define sipNameNr_setAccessTokenUrl 1710
#define sipName_setAccessTokenUrl &sipStrings_QtNetworkAuth[1710]
#define sipNameNr_sip_simplewrapper 1728
#define sipName_sip_simplewrapper &sipStrings_QtNetworkAuth[1728]
#define sipNameNr_NotAuthenticated 1746
#define sipName_NotAuthenticated &sipStrings_QtNetworkAuth[1746]
#define sipNameNr_QOAuth1Signature 1763
#define sipName_QOAuth1Signature &sipStrings_QtNetworkAuth[1763]
#define sipNameNr_authorizationUrl 1780
#define sipName_authorizationUrl &sipStrings_QtNetworkAuth[1780]
#define sipNameNr_callbackReceived 1797
#define sipName_callbackReceived &sipStrings_QtNetworkAuth[1797]
#define sipNameNr_clientIdentifier 1814
#define sipName_clientIdentifier &sipStrings_QtNetworkAuth[1814]
#define sipNameNr_disconnectNotify 1831
#define sipName_disconnectNotify &sipStrings_QtNetworkAuth[1831]
#define sipNameNr_tokenCredentials 1848
#define sipName_tokenCredentials &sipStrings_QtNetworkAuth[1848]
#define sipNameNr_userAgentChanged 1865
#define sipName_userAgentChanged &sipStrings_QtNetworkAuth[1865]
#define sipNameNr_QAbstractOAuth2 1882
#define sipName_QAbstractOAuth2 &sipStrings_QtNetworkAuth[1882]
#define sipNameNr_RefreshingToken 1898
#define sipName_RefreshingToken &sipStrings_QtNetworkAuth[1898]
#define sipNameNr_SignatureMethod 639
#define sipName_SignatureMethod &sipStrings_QtNetworkAuth[639]
#define sipNameNr_clientSharedKey 1914
#define sipName_clientSharedKey &sipStrings_QtNetworkAuth[1914]
#define sipNameNr_setCallbackPath 1930
#define sipName_setCallbackPath &sipStrings_QtNetworkAuth[1930]
#define sipNameNr_setCallbackText 1946
#define sipName_setCallbackText &sipStrings_QtNetworkAuth[1946]
#define sipNameNr_setRefreshToken 1962
#define sipName_setRefreshToken &sipStrings_QtNetworkAuth[1962]
#define sipNameNr_setReplyHandler 1978
#define sipName_setReplyHandler &sipStrings_QtNetworkAuth[1978]
#define sipNameNr_setResponseType 1994
#define sipName_setResponseType &sipStrings_QtNetworkAuth[1994]
#define sipNameNr_signatureMethod 2010
#define sipName_signatureMethod &sipStrings_QtNetworkAuth[2010]
#define sipNameNr_QAbstractOAuth 2026
#define sipName_QAbstractOAuth &sipStrings_QtNetworkAuth[2026]
#define sipNameNr_2041 2041
#define sipName_2041 &sipStrings_QtNetworkAuth[2041]
#define sipNameNr_accessTokenUrl 2056
#define sipName_accessTokenUrl &sipStrings_QtNetworkAuth[2056]
#define sipNameNr_addRequestBody 2071
#define sipName_addRequestBody &sipStrings_QtNetworkAuth[2071]
#define sipNameNr_deleteResource 2086
#define sipName_deleteResource &sipStrings_QtNetworkAuth[2086]
#define sipNameNr_prepareRequest 2101
#define sipName_prepareRequest &sipStrings_QtNetworkAuth[2101]
#define sipNameNr_setContentType 2116
#define sipName_setContentType &sipStrings_QtNetworkAuth[2116]
#define sipNameNr_setTokenSecret 2131
#define sipName_setTokenSecret &sipStrings_QtNetworkAuth[2131]
#define sipNameNr_tokensReceived 2146
#define sipName_tokensReceived &sipStrings_QtNetworkAuth[2146]
#define sipNameNr_connectNotify 1834
#define sipName_connectNotify &sipStrings_QtNetworkAuth[1834]
#define sipNameNr_requestFailed 2161
#define sipName_requestFailed &sipStrings_QtNetworkAuth[2161]
#define sipNameNr_setParameters 2175
#define sipName_setParameters &sipStrings_QtNetworkAuth[2175]
#define sipNameNr_statusChanged 2189
#define sipName_statusChanged &sipStrings_QtNetworkAuth[2189]
#define sipNameNr_NetworkError 2203
#define sipName_NetworkError &sipStrings_QtNetworkAuth[2203]
#define sipNameNr_callbackPath 2216
#define sipName_callbackPath &sipStrings_QtNetworkAuth[2216]
#define sipNameNr_callbackText 2229
#define sipName_callbackText &sipStrings_QtNetworkAuth[2229]
#define sipNameNr_defaultValue 2242
#define sipName_defaultValue &sipStrings_QtNetworkAuth[2242]
#define sipNameNr_expirationAt 2255
#define sipName_expirationAt &sipStrings_QtNetworkAuth[2255]
#define sipNameNr_refreshToken 2268
#define sipName_refreshToken &sipStrings_QtNetworkAuth[2268]
#define sipNameNr_replyHandler 2281
#define sipName_replyHandler &sipStrings_QtNetworkAuth[2281]
#define sipNameNr_responseType 2294
#define sipName_responseType &sipStrings_QtNetworkAuth[2294]
#define sipNameNr_scopeChanged 2307
#define sipName_scopeChanged &sipStrings_QtNetworkAuth[2307]
#define sipNameNr_setUserAgent 2320
#define sipName_setUserAgent &sipStrings_QtNetworkAuth[2320]
#define sipNameNr_stateChanged 2333
#define sipName_stateChanged &sipStrings_QtNetworkAuth[2333]
#define sipNameNr_tokenChanged 2346
#define sipName_tokenChanged &sipStrings_QtNetworkAuth[2346]
#define sipNameNr_ContentType 323
#define sipName_ContentType &sipStrings_QtNetworkAuth[323]
#define sipNameNr_ServerError 2359
#define sipName_ServerError &sipStrings_QtNetworkAuth[2359]
#define sipNameNr_contentType 2371
#define sipName_contentType &sipStrings_QtNetworkAuth[2371]
#define sipNameNr_customEvent 2383
#define sipName_customEvent &sipStrings_QtNetworkAuth[2383]
#define sipNameNr_eventFilter 2395
#define sipName_eventFilter &sipStrings_QtNetworkAuth[2395]
#define sipNameNr_extraTokens 2407
#define sipName_extraTokens &sipStrings_QtNetworkAuth[2407]
#define sipNameNr_isListening 2419
#define sipName_isListening &sipStrings_QtNetworkAuth[2419]
#define sipNameNr_tokenSecret 2431
#define sipName_tokenSecret &sipStrings_QtNetworkAuth[2431]
#define sipNameNr_childEvent 2443
#define sipName_childEvent &sipStrings_QtNetworkAuth[2443]
#define sipNameNr_parameters 2454
#define sipName_parameters &sipStrings_QtNetworkAuth[2454]
#define sipNameNr_timerEvent 2465
#define sipName_timerEvent &sipStrings_QtNetworkAuth[2465]
#define sipNameNr_Hmac_Sha1 2476
#define sipName_Hmac_Sha1 &sipStrings_QtNetworkAuth[2476]
#define sipNameNr_PlainText 2486
#define sipName_PlainText &sipStrings_QtNetworkAuth[2486]
#define sipNameNr_plainText 2496
#define sipName_plainText &sipStrings_QtNetworkAuth[2496]
#define sipNameNr_setStatus 2506
#define sipName_setStatus &sipStrings_QtNetworkAuth[2506]
#define sipNameNr_userAgent 2516
#define sipName_userAgent &sipStrings_QtNetworkAuth[2516]
#define sipNameNr_Rsa_Sha1 2526
#define sipName_Rsa_Sha1 &sipStrings_QtNetworkAuth[2526]
#define sipNameNr_callback 2535
#define sipName_callback &sipStrings_QtNetworkAuth[2535]
#define sipNameNr_finished 2544
#define sipName_finished &sipStrings_QtNetworkAuth[2544]
#define sipNameNr_hmacSha1 2553
#define sipName_hmacSha1 &sipStrings_QtNetworkAuth[2553]
#define sipNameNr_setScope 2562
#define sipName_setScope &sipStrings_QtNetworkAuth[2562]
#define sipNameNr_setState 2571
#define sipName_setState &sipStrings_QtNetworkAuth[2571]
#define sipNameNr_setToken 2580
#define sipName_setToken &sipStrings_QtNetworkAuth[2580]
#define sipNameNr_Granted 2589
#define sipName_Granted &sipStrings_QtNetworkAuth[2589]
#define sipNameNr_NoError 2597
#define sipName_NoError &sipStrings_QtNetworkAuth[2597]
#define sipNameNr_QOAuth1 2605
#define sipName_QOAuth1 &sipStrings_QtNetworkAuth[2605]
#define sipNameNr_Unknown 2613
#define sipName_Unknown &sipStrings_QtNetworkAuth[2613]
#define sipNameNr_address 2621
#define sipName_address &sipStrings_QtNetworkAuth[2621]
#define sipNameNr_granted 2629
#define sipName_granted &sipStrings_QtNetworkAuth[2629]
#define sipNameNr_rsaSha1 2637
#define sipName_rsaSha1 &sipStrings_QtNetworkAuth[2637]
#define sipNameNr_Custom 2645
#define sipName_Custom &sipStrings_QtNetworkAuth[2645]
#define sipNameNr_Delete 2652
#define sipName_Delete &sipStrings_QtNetworkAuth[2652]
#define sipNameNr_Status 864
#define sipName_Status &sipStrings_QtNetworkAuth[864]
#define sipNameNr_insert 2659
#define sipName_insert &sipStrings_QtNetworkAuth[2659]
#define sipNameNr_listen 2666
#define sipName_listen &sipStrings_QtNetworkAuth[2666]
#define sipNameNr_method 2673
#define sipName_method &sipStrings_QtNetworkAuth[2673]
#define sipNameNr_parent 2680
#define sipName_parent &sipStrings_QtNetworkAuth[2680]
#define sipNameNr_setUrl 2687
#define sipName_setUrl &sipStrings_QtNetworkAuth[2687]
#define sipNameNr_status 2694
#define sipName_status &sipStrings_QtNetworkAuth[2694]
#define sipNameNr_Error 155
#define sipName_Error &sipStrings_QtNetworkAuth[155]
#define sipNameNr_Stage 1001
#define sipName_Stage &sipStrings_QtNetworkAuth[1001]
#define sipNameNr_close 2701
#define sipName_close &sipStrings_QtNetworkAuth[2701]
#define sipNameNr_error 2707
#define sipName_error &sipStrings_QtNetworkAuth[2707]
#define sipNameNr_event 2713
#define sipName_event &sipStrings_QtNetworkAuth[2713]
#define sipNameNr_grant 2719
#define sipName_grant &sipStrings_QtNetworkAuth[2719]
#define sipNameNr_nonce 2725
#define sipName_nonce &sipStrings_QtNetworkAuth[2725]
#define sipNameNr_scope 2731
#define sipName_scope &sipStrings_QtNetworkAuth[2731]
#define sipNameNr_setup 2737
#define sipName_setup &sipStrings_QtNetworkAuth[2737]
#define sipNameNr_state 2743
#define sipName_state &sipStrings_QtNetworkAuth[2743]
#define sipNameNr_token 2749
#define sipName_token &sipStrings_QtNetworkAuth[2749]
#define sipNameNr_value 2755
#define sipName_value &sipStrings_QtNetworkAuth[2755]
#define sipNameNr_Head 2761
#define sipName_Head &sipStrings_QtNetworkAuth[2761]
#define sipNameNr_Json 2766
#define sipName_Json &sipStrings_QtNetworkAuth[2766]
#define sipNameNr_Post 2771
#define sipName_Post &sipStrings_QtNetworkAuth[2771]
#define sipNameNr_body 2776
#define sipName_body &sipStrings_QtNetworkAuth[2776]
#define sipNameNr_head 2781
#define sipName_head &sipStrings_QtNetworkAuth[2781]
#define sipNameNr_keys 2786
#define sipName_keys &sipStrings_QtNetworkAuth[2786]
#define sipNameNr_port 2791
#define sipName_port &sipStrings_QtNetworkAuth[2791]
#define sipNameNr_post 2796
#define sipName_post &sipStrings_QtNetworkAuth[2796]
#define sipNameNr_swap 2801
#define sipName_swap &sipStrings_QtNetworkAuth[2801]
#define sipNameNr_take 2806
#define sipName_take &sipStrings_QtNetworkAuth[2806]
#define sipNameNr_Get 2811
#define sipName_Get &sipStrings_QtNetworkAuth[2811]
#define sipNameNr_Put 2815
#define sipName_Put &sipStrings_QtNetworkAuth[2815]
#define sipNameNr_get 2819
#define sipName_get &sipStrings_QtNetworkAuth[2819]
#define sipNameNr_put 2823
#define sipName_put &sipStrings_QtNetworkAuth[2823]
#define sipNameNr_url 2827
#define sipName_url &sipStrings_QtNetworkAuth[2827]

#define sipMalloc                   sipAPI_QtNetworkAuth->api_malloc
#define sipFree                     sipAPI_QtNetworkAuth->api_free
#define sipBuildResult              sipAPI_QtNetworkAuth->api_build_result
#define sipCallMethod               sipAPI_QtNetworkAuth->api_call_method
#define sipCallProcedureMethod      sipAPI_QtNetworkAuth->api_call_procedure_method
#define sipCallErrorHandler         sipAPI_QtNetworkAuth->api_call_error_handler
#define sipParseResultEx            sipAPI_QtNetworkAuth->api_parse_result_ex
#define sipParseResult              sipAPI_QtNetworkAuth->api_parse_result
#define sipParseArgs                sipAPI_QtNetworkAuth->api_parse_args
#define sipParseKwdArgs             sipAPI_QtNetworkAuth->api_parse_kwd_args
#define sipParsePair                sipAPI_QtNetworkAuth->api_parse_pair
#define sipInstanceDestroyed        sipAPI_QtNetworkAuth->api_instance_destroyed
#define sipInstanceDestroyedEx      sipAPI_QtNetworkAuth->api_instance_destroyed_ex
#define sipConvertFromSequenceIndex sipAPI_QtNetworkAuth->api_convert_from_sequence_index
#define sipConvertFromSliceObject   sipAPI_QtNetworkAuth->api_convert_from_slice_object
#define sipConvertFromVoidPtr       sipAPI_QtNetworkAuth->api_convert_from_void_ptr
#define sipConvertToVoidPtr         sipAPI_QtNetworkAuth->api_convert_to_void_ptr
#define sipAddException             sipAPI_QtNetworkAuth->api_add_exception
#define sipNoFunction               sipAPI_QtNetworkAuth->api_no_function
#define sipNoMethod                 sipAPI_QtNetworkAuth->api_no_method
#define sipAbstractMethod           sipAPI_QtNetworkAuth->api_abstract_method
#define sipBadClass                 sipAPI_QtNetworkAuth->api_bad_class
#define sipBadCatcherResult         sipAPI_QtNetworkAuth->api_bad_catcher_result
#define sipBadCallableArg           sipAPI_QtNetworkAuth->api_bad_callable_arg
#define sipBadOperatorArg           sipAPI_QtNetworkAuth->api_bad_operator_arg
#define sipTrace                    sipAPI_QtNetworkAuth->api_trace
#define sipTransferBack             sipAPI_QtNetworkAuth->api_transfer_back
#define sipTransferTo               sipAPI_QtNetworkAuth->api_transfer_to
#define sipSimpleWrapper_Type       sipAPI_QtNetworkAuth->api_simplewrapper_type
#define sipWrapper_Type             sipAPI_QtNetworkAuth->api_wrapper_type
#define sipWrapperType_Type         sipAPI_QtNetworkAuth->api_wrappertype_type
#define sipVoidPtr_Type             sipAPI_QtNetworkAuth->api_voidptr_type
#define sipGetPyObject              sipAPI_QtNetworkAuth->api_get_pyobject
#define sipGetAddress               sipAPI_QtNetworkAuth->api_get_address
#define sipGetMixinAddress          sipAPI_QtNetworkAuth->api_get_mixin_address
#define sipGetCppPtr                sipAPI_QtNetworkAuth->api_get_cpp_ptr
#define sipGetComplexCppPtr         sipAPI_QtNetworkAuth->api_get_complex_cpp_ptr
#define sipCallHook                 sipAPI_QtNetworkAuth->api_call_hook
#define sipEndThread                sipAPI_QtNetworkAuth->api_end_thread
#define sipRaiseUnknownException    sipAPI_QtNetworkAuth->api_raise_unknown_exception
#define sipRaiseTypeException       sipAPI_QtNetworkAuth->api_raise_type_exception
#define sipBadLengthForSlice        sipAPI_QtNetworkAuth->api_bad_length_for_slice
#define sipAddTypeInstance          sipAPI_QtNetworkAuth->api_add_type_instance
#define sipPySlotExtend             sipAPI_QtNetworkAuth->api_pyslot_extend
#define sipAddDelayedDtor           sipAPI_QtNetworkAuth->api_add_delayed_dtor
#define sipCanConvertToType         sipAPI_QtNetworkAuth->api_can_convert_to_type
#define sipConvertToType            sipAPI_QtNetworkAuth->api_convert_to_type
#define sipForceConvertToType       sipAPI_QtNetworkAuth->api_force_convert_to_type
#define sipConvertToEnum            sipAPI_QtNetworkAuth->api_convert_to_enum
#define sipConvertToBool            sipAPI_QtNetworkAuth->api_convert_to_bool
#define sipReleaseType              sipAPI_QtNetworkAuth->api_release_type
#define sipConvertFromType          sipAPI_QtNetworkAuth->api_convert_from_type
#define sipConvertFromNewType       sipAPI_QtNetworkAuth->api_convert_from_new_type
#define sipConvertFromNewPyType     sipAPI_QtNetworkAuth->api_convert_from_new_pytype
#define sipConvertFromEnum          sipAPI_QtNetworkAuth->api_convert_from_enum
#define sipGetState                 sipAPI_QtNetworkAuth->api_get_state
#define sipExportSymbol             sipAPI_QtNetworkAuth->api_export_symbol
#define sipImportSymbol             sipAPI_QtNetworkAuth->api_import_symbol
#define sipFindType                 sipAPI_QtNetworkAuth->api_find_type
#define sipBytes_AsChar             sipAPI_QtNetworkAuth->api_bytes_as_char
#define sipBytes_AsString           sipAPI_QtNetworkAuth->api_bytes_as_string
#define sipString_AsASCIIChar       sipAPI_QtNetworkAuth->api_string_as_ascii_char
#define sipString_AsASCIIString     sipAPI_QtNetworkAuth->api_string_as_ascii_string
#define sipString_AsLatin1Char      sipAPI_QtNetworkAuth->api_string_as_latin1_char
#define sipString_AsLatin1String    sipAPI_QtNetworkAuth->api_string_as_latin1_string
#define sipString_AsUTF8Char        sipAPI_QtNetworkAuth->api_string_as_utf8_char
#define sipString_AsUTF8String      sipAPI_QtNetworkAuth->api_string_as_utf8_string
#define sipUnicode_AsWChar          sipAPI_QtNetworkAuth->api_unicode_as_wchar
#define sipUnicode_AsWString        sipAPI_QtNetworkAuth->api_unicode_as_wstring
#define sipConvertFromConstVoidPtr  sipAPI_QtNetworkAuth->api_convert_from_const_void_ptr
#define sipConvertFromVoidPtrAndSize    sipAPI_QtNetworkAuth->api_convert_from_void_ptr_and_size
#define sipConvertFromConstVoidPtrAndSize   sipAPI_QtNetworkAuth->api_convert_from_const_void_ptr_and_size
#define sipWrappedTypeName(wt)      ((wt)->wt_td->td_cname)
#define sipGetReference             sipAPI_QtNetworkAuth->api_get_reference
#define sipKeepReference            sipAPI_QtNetworkAuth->api_keep_reference
#define sipRegisterProxyResolver    sipAPI_QtNetworkAuth->api_register_proxy_resolver
#define sipRegisterPyType           sipAPI_QtNetworkAuth->api_register_py_type
#define sipTypeFromPyTypeObject     sipAPI_QtNetworkAuth->api_type_from_py_type_object
#define sipTypeScope                sipAPI_QtNetworkAuth->api_type_scope
#define sipResolveTypedef           sipAPI_QtNetworkAuth->api_resolve_typedef
#define sipRegisterAttributeGetter  sipAPI_QtNetworkAuth->api_register_attribute_getter
#define sipEnableAutoconversion     sipAPI_QtNetworkAuth->api_enable_autoconversion
#define sipInitMixin                sipAPI_QtNetworkAuth->api_init_mixin
#define sipExportModule             sipAPI_QtNetworkAuth->api_export_module
#define sipInitModule               sipAPI_QtNetworkAuth->api_init_module
#define sipGetInterpreter           sipAPI_QtNetworkAuth->api_get_interpreter
#define sipSetTypeUserData          sipAPI_QtNetworkAuth->api_set_type_user_data
#define sipGetTypeUserData          sipAPI_QtNetworkAuth->api_get_type_user_data
#define sipPyTypeDict               sipAPI_QtNetworkAuth->api_py_type_dict
#define sipPyTypeName               sipAPI_QtNetworkAuth->api_py_type_name
#define sipGetCFunction             sipAPI_QtNetworkAuth->api_get_c_function
#define sipGetMethod                sipAPI_QtNetworkAuth->api_get_method
#define sipFromMethod               sipAPI_QtNetworkAuth->api_from_method
#define sipGetDate                  sipAPI_QtNetworkAuth->api_get_date
#define sipFromDate                 sipAPI_QtNetworkAuth->api_from_date
#define sipGetDateTime              sipAPI_QtNetworkAuth->api_get_datetime
#define sipFromDateTime             sipAPI_QtNetworkAuth->api_from_datetime
#define sipGetTime                  sipAPI_QtNetworkAuth->api_get_time
#define sipFromTime                 sipAPI_QtNetworkAuth->api_from_time
#define sipIsUserType               sipAPI_QtNetworkAuth->api_is_user_type
#define sipCheckPluginForType       sipAPI_QtNetworkAuth->api_check_plugin_for_type
#define sipUnicodeNew               sipAPI_QtNetworkAuth->api_unicode_new
#define sipUnicodeWrite             sipAPI_QtNetworkAuth->api_unicode_write
#define sipUnicodeData              sipAPI_QtNetworkAuth->api_unicode_data
#define sipGetBufferInfo            sipAPI_QtNetworkAuth->api_get_buffer_info
#define sipReleaseBufferInfo        sipAPI_QtNetworkAuth->api_release_buffer_info
#define sipIsOwnedByPython          sipAPI_QtNetworkAuth->api_is_owned_by_python
#define sipIsDerivedClass           sipAPI_QtNetworkAuth->api_is_derived_class
#define sipGetUserObject            sipAPI_QtNetworkAuth->api_get_user_object
#define sipSetUserObject            sipAPI_QtNetworkAuth->api_set_user_object
#define sipRegisterEventHandler     sipAPI_QtNetworkAuth->api_register_event_handler
#define sipConvertToArray           sipAPI_QtNetworkAuth->api_convert_to_array
#define sipConvertToTypedArray      sipAPI_QtNetworkAuth->api_convert_to_typed_array
#define sipEnableGC                 sipAPI_QtNetworkAuth->api_enable_gc
#define sipPrintObject              sipAPI_QtNetworkAuth->api_print_object
#define sipLong_AsChar              sipAPI_QtNetworkAuth->api_long_as_char
#define sipLong_AsSignedChar        sipAPI_QtNetworkAuth->api_long_as_signed_char
#define sipLong_AsUnsignedChar      sipAPI_QtNetworkAuth->api_long_as_unsigned_char
#define sipLong_AsShort             sipAPI_QtNetworkAuth->api_long_as_short
#define sipLong_AsUnsignedShort     sipAPI_QtNetworkAuth->api_long_as_unsigned_short
#define sipLong_AsInt               sipAPI_QtNetworkAuth->api_long_as_int
#define sipLong_AsUnsignedInt       sipAPI_QtNetworkAuth->api_long_as_unsigned_int
#define sipLong_AsLong              sipAPI_QtNetworkAuth->api_long_as_long
#define sipLong_AsUnsignedLong      sipAPI_QtNetworkAuth->api_long_as_unsigned_long
#define sipLong_AsLongLong          sipAPI_QtNetworkAuth->api_long_as_long_long
#define sipLong_AsUnsignedLongLong  sipAPI_QtNetworkAuth->api_long_as_unsigned_long_long
#define sipLong_AsSizeT             sipAPI_QtNetworkAuth->api_long_as_size_t
#define sipVisitWrappers            sipAPI_QtNetworkAuth->api_visit_wrappers
#define sipRegisterExitNotifier     sipAPI_QtNetworkAuth->api_register_exit_notifier
#define sipDeprecated               sipAPI_QtNetworkAuth->api_deprecated
#define sipPyTypeDictRef            sipAPI_QtNetworkAuth->api_py_type_dict_ref
#define sipNextExceptionHandler     sipAPI_QtNetworkAuth->api_next_exception_handler
#define sipSetNewUserTypeHandler    sipAPI_QtNetworkAuth->api_set_new_user_type_handler
#define sipGetFrame                 sipAPI_QtNetworkAuth->api_get_frame
#define sipSetDestroyOnExit         sipAPI_QtNetworkAuth->api_set_destroy_on_exit
#define sipEnableOverflowChecking   sipAPI_QtNetworkAuth->api_enable_overflow_checking
#define sipIsAPIEnabled             sipAPI_QtNetworkAuth->api_is_api_enabled
#define sipClearAnySlotReference    sipAPI_QtNetworkAuth->api_clear_any_slot_reference
#define sipConnectRx                sipAPI_QtNetworkAuth->api_connect_rx
#define sipConvertRx                sipAPI_QtNetworkAuth->api_convert_rx
#define sipDisconnectRx             sipAPI_QtNetworkAuth->api_disconnect_rx
#define sipFreeSipslot              sipAPI_QtNetworkAuth->api_free_sipslot
#define sipInvokeSlot               sipAPI_QtNetworkAuth->api_invoke_slot
#define sipInvokeSlotEx             sipAPI_QtNetworkAuth->api_invoke_slot_ex
#define sipSameSlot                 sipAPI_QtNetworkAuth->api_same_slot
#define sipSaveSlot                 sipAPI_QtNetworkAuth->api_save_slot
#define sipVisitSlot                sipAPI_QtNetworkAuth->api_visit_slot
#define sipIsPyMethod               sipAPI_QtNetworkAuth->api_is_py_method_12_8

/* The strings used by this module. */
extern const char sipStrings_QtNetworkAuth[];

#define sipType_QAbstractOAuth sipExportedTypes_QtNetworkAuth[0]

#define sipType_QAbstractOAuth_ContentType sipExportedTypes_QtNetworkAuth[2]

#define sipType_QAbstractOAuth_Error sipExportedTypes_QtNetworkAuth[3]

#define sipType_QAbstractOAuth_Stage sipExportedTypes_QtNetworkAuth[4]

#define sipType_QAbstractOAuth_Status sipExportedTypes_QtNetworkAuth[5]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QAbstractOAuth;

#define sipType_QAbstractOAuth2 sipExportedTypes_QtNetworkAuth[1]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QAbstractOAuth2;

#define sipType_QAbstractOAuthReplyHandler sipExportedTypes_QtNetworkAuth[6]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QAbstractOAuthReplyHandler;

#define sipType_QOAuth1 sipExportedTypes_QtNetworkAuth[8]

#define sipType_QOAuth1_SignatureMethod sipExportedTypes_QtNetworkAuth[9]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuth1;

#define sipType_QOAuth1Signature sipExportedTypes_QtNetworkAuth[10]

#define sipType_QOAuth1Signature_HttpRequestMethod sipExportedTypes_QtNetworkAuth[11]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuth1Signature;

#define sipType_QOAuth2AuthorizationCodeFlow sipExportedTypes_QtNetworkAuth[12]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuth2AuthorizationCodeFlow;

#define sipType_QOAuthOobReplyHandler sipExportedTypes_QtNetworkAuth[14]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuthOobReplyHandler;

#define sipType_QOAuthHttpServerReplyHandler sipExportedTypes_QtNetworkAuth[13]

extern sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuthHttpServerReplyHandler;

#define sipType_QList_0100QString sipExportedTypes_QtNetworkAuth[7]

extern sipMappedTypeDef sipTypeDef_QtNetworkAuth_QList_0100QString;

#define sipType_QPair_0100QString_0100QString sipExportedTypes_QtNetworkAuth[15]

extern sipMappedTypeDef sipTypeDef_QtNetworkAuth_QPair_0100QString_0100QString;

/* The SIP API, this module's API and the APIs of any imported modules. */
extern const sipAPIDef *sipAPI_QtNetworkAuth;
extern sipExportedModuleDef sipModuleAPI_QtNetworkAuth;
extern sipTypeDef *sipExportedTypes_QtNetworkAuth[];

#define sipType_QObject sipImportedTypes_QtNetworkAuth_QtCore[5].it_td

#define sipType_QByteArray sipImportedTypes_QtNetworkAuth_QtCore[0].it_td

#define sipType_QEvent sipImportedTypes_QtNetworkAuth_QtCore[3].it_td

#define sipType_QTimerEvent sipImportedTypes_QtNetworkAuth_QtCore[7].it_td

#define sipType_QChildEvent sipImportedTypes_QtNetworkAuth_QtCore[1].it_td

#define sipType_QDateTime sipImportedTypes_QtNetworkAuth_QtCore[2].it_td

#define sipType_QMetaMethod sipImportedTypes_QtNetworkAuth_QtCore[4].it_td

#define sipType_QUrl sipImportedTypes_QtNetworkAuth_QtCore[8].it_td

#define sipType_QUrlQuery sipImportedTypes_QtNetworkAuth_QtCore[9].it_td

#define sipType_QVariant sipImportedTypes_QtNetworkAuth_QtCore[10].it_td

#define sipType_QVariantMap sipImportedTypes_QtNetworkAuth_QtCore[11].it_td

#define sipType_QString sipImportedTypes_QtNetworkAuth_QtCore[6].it_td
extern sipImportedTypeDef sipImportedTypes_QtNetworkAuth_QtCore[];
extern sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[];

#define sipType_QHostAddress sipImportedTypes_QtNetworkAuth_QtNetwork[0].it_td

#define sipType_QHttpMultiPart sipImportedTypes_QtNetworkAuth_QtNetwork[1].it_td

#define sipType_QNetworkAccessManager sipImportedTypes_QtNetworkAuth_QtNetwork[2].it_td

#define sipType_QNetworkAccessManager_Operation sipImportedTypes_QtNetworkAuth_QtNetwork[3].it_td

#define sipType_QNetworkReply sipImportedTypes_QtNetworkAuth_QtNetwork[4].it_td

#define sipType_QNetworkRequest sipImportedTypes_QtNetworkAuth_QtNetwork[5].it_td
extern sipImportedTypeDef sipImportedTypes_QtNetworkAuth_QtNetwork[];

typedef const QMetaObject *(*sip_qt_metaobject_func)(sipSimpleWrapper *, sipTypeDef *);
extern sip_qt_metaobject_func sip_QtNetworkAuth_qt_metaobject;

typedef int (*sip_qt_metacall_func)(sipSimpleWrapper *, sipTypeDef *, QMetaObject::Call, int, void **);
extern sip_qt_metacall_func sip_QtNetworkAuth_qt_metacall;

typedef bool (*sip_qt_metacast_func)(sipSimpleWrapper *, const sipTypeDef *, const char *, void **);
extern sip_qt_metacast_func sip_QtNetworkAuth_qt_metacast;
#line 236 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
// Imports from QtCore.
typedef void (*pyqt5_qtnetworkauth_err_print_t)();
extern pyqt5_qtnetworkauth_err_print_t pyqt5_qtnetworkauth_err_print;
#line 692 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipAPIQtNetworkAuth.h"

#endif
