/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtNetworkAuth.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetworkAuth.h"

#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauthhttpserverreplyhandler.sip"
#include <qoauthhttpserverreplyhandler.h>
#line 29 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qhostaddress.sip"
#include <qhostaddress.h>
#line 36 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 39 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 42 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 45 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 48 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 53 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 56 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 59 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 62 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 68 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 71 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 74 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 77 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 80 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 83 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 86 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 89 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 92 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQOAuthHttpServerReplyHandler.cpp"


class sipQOAuthHttpServerReplyHandler : public ::QOAuthHttpServerReplyHandler
{
public:
    sipQOAuthHttpServerReplyHandler(::QObject*);
    sipQOAuthHttpServerReplyHandler(::quint16, ::QObject*);
    sipQOAuthHttpServerReplyHandler(const ::QHostAddress&, ::quint16, ::QObject*);
    virtual ~sipQOAuthHttpServerReplyHandler();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void networkReplyFinished(::QNetworkReply*) SIP_OVERRIDE;
    ::QString callback() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQOAuthHttpServerReplyHandler(const sipQOAuthHttpServerReplyHandler &);
    sipQOAuthHttpServerReplyHandler &operator = (const sipQOAuthHttpServerReplyHandler &);

    char sipPyMethods[9];
};

sipQOAuthHttpServerReplyHandler::sipQOAuthHttpServerReplyHandler(::QObject*a0): ::QOAuthHttpServerReplyHandler(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOAuthHttpServerReplyHandler::sipQOAuthHttpServerReplyHandler(::quint16 a0, ::QObject*a1): ::QOAuthHttpServerReplyHandler(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOAuthHttpServerReplyHandler::sipQOAuthHttpServerReplyHandler(const ::QHostAddress& a0, ::quint16 a1, ::QObject*a2): ::QOAuthHttpServerReplyHandler(a0, a1, a2), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQOAuthHttpServerReplyHandler::~sipQOAuthHttpServerReplyHandler()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQOAuthHttpServerReplyHandler::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtNetworkAuth_qt_metaobject(sipPySelf, sipType_QOAuthHttpServerReplyHandler);

    return ::QOAuthHttpServerReplyHandler::metaObject();
}

int sipQOAuthHttpServerReplyHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QOAuthHttpServerReplyHandler::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtNetworkAuth_qt_metacall(sipPySelf, sipType_QOAuthHttpServerReplyHandler, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQOAuthHttpServerReplyHandler::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtNetworkAuth_qt_metacast(sipPySelf, sipType_QOAuthHttpServerReplyHandler, _clname, &sipCpp) ? sipCpp : ::QOAuthHttpServerReplyHandler::qt_metacast(_clname));
}

void sipQOAuthHttpServerReplyHandler::networkReplyFinished(::QNetworkReply*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_networkReplyFinished);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::networkReplyFinished(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_13(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QNetworkReply*);

    sipVH_QtNetworkAuth_13(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQOAuthHttpServerReplyHandler::callback() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_callback);

    if (!sipMeth)
        return ::QOAuthHttpServerReplyHandler::callback();

    extern ::QString sipVH_QtNetworkAuth_12(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtNetworkAuth_12(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQOAuthHttpServerReplyHandler::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QOAuthHttpServerReplyHandler::event(a0);

    extern bool sipVH_QtNetworkAuth_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtNetworkAuth_5(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQOAuthHttpServerReplyHandler::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QOAuthHttpServerReplyHandler::eventFilter(a0, a1);

    extern bool sipVH_QtNetworkAuth_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtNetworkAuth_4(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQOAuthHttpServerReplyHandler::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::timerEvent(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtNetworkAuth_3(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOAuthHttpServerReplyHandler::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::childEvent(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtNetworkAuth_2(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOAuthHttpServerReplyHandler::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::customEvent(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtNetworkAuth_1(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOAuthHttpServerReplyHandler::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::connectNotify(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetworkAuth_0(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQOAuthHttpServerReplyHandler::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QOAuthHttpServerReplyHandler::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtNetworkAuth_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtNetworkAuth_0(sipGILState, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_callback, "callback(self) -> str");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_callback(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_callback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QOAuthHttpServerReplyHandler::callback() : sipCpp->callback()));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_callback, doc_QOAuthHttpServerReplyHandler_callback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_callbackPath, "callbackPath(self) -> str");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_callbackPath(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_callbackPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->callbackPath());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_callbackPath, doc_QOAuthHttpServerReplyHandler_callbackPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_setCallbackPath, "setCallbackPath(self, path: str|None)");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_setCallbackPath(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_setCallbackPath(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCallbackPath(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_setCallbackPath, doc_QOAuthHttpServerReplyHandler_setCallbackPath);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_callbackText, "callbackText(self) -> str");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_callbackText(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_callbackText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->callbackText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_callbackText, doc_QOAuthHttpServerReplyHandler_callbackText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_setCallbackText, "setCallbackText(self, text: str|None)");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_setCallbackText(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_setCallbackText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setCallbackText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_setCallbackText, doc_QOAuthHttpServerReplyHandler_setCallbackText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_port, "port(self) -> int");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_port(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_port(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            ::quint16 sipRes;

            sipRes = sipCpp->port();

            return PyLong_FromUnsignedLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_port, doc_QOAuthHttpServerReplyHandler_port);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_listen, "listen(self, address: QHostAddress|QHostAddress.SpecialAddress = QHostAddress.SpecialAddress.Any, port: int = 0) -> bool");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_listen(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_listen(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QHostAddress& a0def = QHostAddress::SpecialAddress::Any;
        const ::QHostAddress* a0 = &a0def;
        int a0State = 0;
        ::quint16 a1 = 0;
        ::QOAuthHttpServerReplyHandler *sipCpp;

        static const char *sipKwdList[] = {
            sipName_address,
            sipName_port,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "B|J1t", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp, sipType_QHostAddress, &a0, &a0State, &a1))
        {
            bool sipRes;

            sipRes = sipCpp->listen(*a0, a1);
            sipReleaseType(const_cast< ::QHostAddress *>(a0), sipType_QHostAddress, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_listen, doc_QOAuthHttpServerReplyHandler_listen);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_close, "close(self)");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_close(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_close(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            sipCpp->close();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_close, doc_QOAuthHttpServerReplyHandler_close);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler_isListening, "isListening(self) -> bool");

extern "C" {static PyObject *meth_QOAuthHttpServerReplyHandler_isListening(PyObject *, PyObject *);}
static PyObject *meth_QOAuthHttpServerReplyHandler_isListening(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QOAuthHttpServerReplyHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QOAuthHttpServerReplyHandler, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isListening();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QOAuthHttpServerReplyHandler, sipName_isListening, doc_QOAuthHttpServerReplyHandler_isListening);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QOAuthHttpServerReplyHandler(void *, const sipTypeDef *);}
static void *cast_QOAuthHttpServerReplyHandler(void *sipCppV, const sipTypeDef *targetType)
{
    ::QOAuthHttpServerReplyHandler *sipCpp = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(sipCppV);

    if (targetType == sipType_QOAuthHttpServerReplyHandler)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QOAuthOobReplyHandler)->ctd_cast(static_cast< ::QOAuthOobReplyHandler *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QOAuthHttpServerReplyHandler(void *, int);}
static void release_QOAuthHttpServerReplyHandler(void *sipCppV, int)
{
    ::QOAuthHttpServerReplyHandler *sipCpp = reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QOAuthHttpServerReplyHandler(Py_ssize_t);}
static void *array_QOAuthHttpServerReplyHandler(Py_ssize_t sipNrElem)
{
    return new ::QOAuthHttpServerReplyHandler[sipNrElem];
}


extern "C" {static void array_delete_QOAuthHttpServerReplyHandler(void *);}
static void array_delete_QOAuthHttpServerReplyHandler(void *sipCpp)
{
    delete[] reinterpret_cast< ::QOAuthHttpServerReplyHandler *>(sipCpp);
}


extern "C" {static void dealloc_QOAuthHttpServerReplyHandler(sipSimpleWrapper *);}
static void dealloc_QOAuthHttpServerReplyHandler(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQOAuthHttpServerReplyHandler *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QOAuthHttpServerReplyHandler(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QOAuthHttpServerReplyHandler(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QOAuthHttpServerReplyHandler(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQOAuthHttpServerReplyHandler *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQOAuthHttpServerReplyHandler(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::quint16 a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "t|JH", &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQOAuthHttpServerReplyHandler(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QHostAddress* a0;
        int a0State = 0;
        ::quint16 a1;
        ::QObject* a2 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1t|JH", sipType_QHostAddress, &a0, &a0State, &a1, sipType_QObject, &a2, sipOwner))
        {
            sipCpp = new sipQOAuthHttpServerReplyHandler(*a0, a1, a2);
            sipReleaseType(const_cast< ::QHostAddress *>(a0), sipType_QHostAddress, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QOAuthHttpServerReplyHandler[] = {{14, 255, 1}};


static PyMethodDef methods_QOAuthHttpServerReplyHandler[] = {
    {sipName_callback, meth_QOAuthHttpServerReplyHandler_callback, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_callback},
    {sipName_callbackPath, meth_QOAuthHttpServerReplyHandler_callbackPath, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_callbackPath},
    {sipName_callbackText, meth_QOAuthHttpServerReplyHandler_callbackText, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_callbackText},
    {sipName_close, meth_QOAuthHttpServerReplyHandler_close, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_close},
    {sipName_isListening, meth_QOAuthHttpServerReplyHandler_isListening, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_isListening},
    {sipName_listen, SIP_MLMETH_CAST(meth_QOAuthHttpServerReplyHandler_listen), METH_VARARGS|METH_KEYWORDS, doc_QOAuthHttpServerReplyHandler_listen},
    {sipName_port, meth_QOAuthHttpServerReplyHandler_port, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_port},
    {sipName_setCallbackPath, meth_QOAuthHttpServerReplyHandler_setCallbackPath, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_setCallbackPath},
    {sipName_setCallbackText, meth_QOAuthHttpServerReplyHandler_setCallbackText, METH_VARARGS, doc_QOAuthHttpServerReplyHandler_setCallbackText}
};

PyDoc_STRVAR(doc_QOAuthHttpServerReplyHandler, "\1QOAuthHttpServerReplyHandler(parent: QObject|None = None)\n"
"QOAuthHttpServerReplyHandler(port: int, parent: QObject|None = None)\n"
"QOAuthHttpServerReplyHandler(address: QHostAddress|QHostAddress.SpecialAddress, port: int, parent: QObject|None = None)");


static pyqt5ClassPluginDef plugin_QOAuthHttpServerReplyHandler = {
    &::QOAuthHttpServerReplyHandler::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetworkAuth_QOAuthHttpServerReplyHandler = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QOAuthHttpServerReplyHandler,
        SIP_NULLPTR,
        &plugin_QOAuthHttpServerReplyHandler,
    },
    {
        sipNameNr_QOAuthHttpServerReplyHandler,
        {0, 0, 1},
        9, methods_QOAuthHttpServerReplyHandler,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QOAuthHttpServerReplyHandler,
    -1,
    -1,
    supers_QOAuthHttpServerReplyHandler,
    SIP_NULLPTR,
    init_type_QOAuthHttpServerReplyHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QOAuthHttpServerReplyHandler,
    SIP_NULLPTR,
    array_QOAuthHttpServerReplyHandler,
    SIP_NULLPTR,
    release_QOAuthHttpServerReplyHandler,
    cast_QOAuthHttpServerReplyHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QOAuthHttpServerReplyHandler,
    sizeof (::QOAuthHttpServerReplyHandler),
};
