/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtNetworkAuth.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetworkAuth.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 32 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 35 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 38 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 41 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 44 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 109 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qurl.sip"
#include <qurl.h>
#line 47 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 50 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 53 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 45 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qhttpmultipart.sip"
#include <qhttpmultipart.h>
#line 56 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauth1.sip"
#include <qoauth1.h>
#line 62 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauth1signature.sip"
#include <qoauth1signature.h>
#line 65 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauth2authorizationcodeflow.sip"
#include <qoauth2authorizationcodeflow.h>
#line 68 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauthoobreplyhandler.sip"
#include <qoauthoobreplyhandler.h>
#line 71 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qoauthhttpserverreplyhandler.sip"
#include <qoauthhttpserverreplyhandler.h>
#line 74 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtNetworkAuth[] = {
    'Q', 'O', 'A', 'u', 't', 'h', '1', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', ':', ':', 'H', 't', 't', 'p', 'R', 'e', 'q', 'u', 'e', 's', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'R', 'e', 'q', 'u', 'e', 's', 't', 'i', 'n', 'g', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'O', 'A', 'u', 't', 'h', 'T', 'o', 'k', 'e', 'n', 'S', 'e', 'c', 'r', 'e', 't', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'Q', 'O', 'A', 'u', 't', 'h', '2', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'C', 'o', 'd', 'e', 'F', 'l', 'o', 'w', 0,
    'Q', 'O', 'A', 'u', 't', 'h', 'H', 't', 't', 'p', 'S', 'e', 'r', 'v', 'e', 'r', 'R', 'e', 'p', 'l', 'y', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    's', 'e', 't', 'C', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', ':', ':', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'e', 'a', 'd', 'e', 'r', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    's', 'e', 't', 'M', 'o', 'd', 'i', 'f', 'y', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', 'R', 'e', 'p', 'l', 'y', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'O', 'w', 'n', 'e', 'r', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 0,
    't', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'd', 'S', 'e', 'c', 'r', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', 'G', 'r', 'a', 'n', 't', 'W', 'i', 't', 'h', 'V', 'e', 'r', 'i', 'f', 'i', 'e', 'r', 0,
    'O', 'A', 'u', 't', 'h', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'N', 'o', 't', 'V', 'e', 'r', 'i', 'f', 'i', 'e', 'd', 0,
    'Q', 'O', 'A', 'u', 't', 'h', '1', ':', ':', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'm', 'o', 'd', 'i', 'f', 'y', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 'F', 'u', 'n', 'c', 't', 'i', 'o', 'n', 0,
    'O', 'A', 'u', 't', 'h', 'T', 'o', 'k', 'e', 'n', 'N', 'o', 't', 'F', 'o', 'u', 'n', 'd', 'E', 'r', 'r', 'o', 'r', 0,
    'R', 'e', 'q', 'u', 'e', 's', 't', 'i', 'n', 'g', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'T', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    's', 'e', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 'P', 'a', 'i', 'r', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', ',', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 'd', 'U', 'r', 'l', 0,
    's', 'e', 't', 'T', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 0,
    's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 'M', 'e', 't', 'h', 'o', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', ':', ':', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', ':', ':', 'S', 't', 'a', 'g', 'e', 0,
    'Q', 'O', 'A', 'u', 't', 'h', 'O', 'o', 'b', 'R', 'e', 'p', 'l', 'y', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'R', 'e', 'f', 'r', 'e', 's', 'h', 'i', 'n', 'g', 'A', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 0,
    'R', 'e', 'q', 'u', 'e', 's', 't', 'i', 'n', 'g', 'A', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 0,
    'a', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 'U', 'r', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'l', 'i', 'e', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'd', 'S', 'e', 'c', 'r', 'e', 't', 0,
    's', 'e', 't', 'C', 'u', 's', 't', 'o', 'm', 'M', 'e', 't', 'h', 'o', 'd', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'e', 'W', 'i', 't', 'h', 'B', 'r', 'o', 'w', 's', 'e', 'r', 0,
    'b', 'u', 'i', 'l', 'd', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 'U', 'r', 'l', 0,
    'c', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'D', 'a', 't', 'a', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'R', 'a', 'n', 'd', 'o', 'm', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'c', 'c', 'e', 's', 's', 'M', 'a', 'n', 'a', 'g', 'e', 'r', 0,
    'n', 'e', 't', 'w', 'o', 'r', 'k', 'R', 'e', 'p', 'l', 'y', 'F', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    's', 'e', 't', 'C', 'l', 'i', 'e', 'n', 't', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    's', 'e', 't', 'H', 't', 't', 'p', 'R', 'e', 'q', 'u', 'e', 's', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'N', 'e', 't', 'w', 'o', 'r', 'k', 'A', 'u', 't', 'h', 0,
    'e', 'x', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'A', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'T', 'o', 'k', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 's', 'p', 'o', 'n', 's', 'e', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'U', 'r', 'l', 0,
    's', 'e', 't', 'C', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    's', 'e', 't', 'T', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    't', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 'U', 'r', 'l', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'd', 'S', 'e', 'c', 'r', 'e', 't', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'M', 'e', 't', 'h', 'o', 'd', 'S', 't', 'r', 'i', 'n', 'g', 0,
    'e', 'x', 't', 'r', 'a', 'T', 'o', 'k', 'e', 'n', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'A', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'A', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 0,
    's', 'e', 't', 'C', 'l', 'i', 'e', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    's', 'e', 't', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 'M', 'e', 't', 'h', 'o', 'd', 0,
    't', 'o', 'k', 'e', 'n', 'S', 'e', 'c', 'r', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'W', 'w', 'w', 'F', 'o', 'r', 'm', 'U', 'r', 'l', 'E', 'n', 'c', 'o', 'd', 'e', 'd', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    'h', 't', 't', 'p', 'R', 'e', 'q', 'u', 'e', 's', 't', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'r', 'e', 'p', 'l', 'y', 'D', 'a', 't', 'a', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 'U', 'r', 'l', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'N', 'o', 't', 'A', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 'd', 0,
    'Q', 'O', 'A', 'u', 't', 'h', '1', 'S', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 0,
    'a', 'u', 't', 'h', 'o', 'r', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'U', 'r', 'l', 0,
    'c', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'I', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    't', 'o', 'k', 'e', 'n', 'C', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', 0,
    'u', 's', 'e', 'r', 'A', 'g', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', '2', 0,
    'R', 'e', 'f', 'r', 'e', 's', 'h', 'i', 'n', 'g', 'T', 'o', 'k', 'e', 'n', 0,
    'c', 'l', 'i', 'e', 'n', 't', 'S', 'h', 'a', 'r', 'e', 'd', 'K', 'e', 'y', 0,
    's', 'e', 't', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'P', 'a', 't', 'h', 0,
    's', 'e', 't', 'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'R', 'e', 'f', 'r', 'e', 's', 'h', 'T', 'o', 'k', 'e', 'n', 0,
    's', 'e', 't', 'R', 'e', 'p', 'l', 'y', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    's', 'e', 't', 'R', 'e', 's', 'p', 'o', 'n', 's', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 'M', 'e', 't', 'h', 'o', 'd', 0,
    'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'O', 'A', 'u', 't', 'h', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'S', 't', 'r', 'i', 'n', 'g', '>', 0,
    'a', 'c', 'c', 'e', 's', 's', 'T', 'o', 'k', 'e', 'n', 'U', 'r', 'l', 0,
    'a', 'd', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'B', 'o', 'd', 'y', 0,
    'd', 'e', 'l', 'e', 't', 'e', 'R', 'e', 's', 'o', 'u', 'r', 'c', 'e', 0,
    'p', 'r', 'e', 'p', 'a', 'r', 'e', 'R', 'e', 'q', 'u', 'e', 's', 't', 0,
    's', 'e', 't', 'C', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    's', 'e', 't', 'T', 'o', 'k', 'e', 'n', 'S', 'e', 'c', 'r', 'e', 't', 0,
    't', 'o', 'k', 'e', 'n', 's', 'R', 'e', 'c', 'e', 'i', 'v', 'e', 'd', 0,
    'r', 'e', 'q', 'u', 'e', 's', 't', 'F', 'a', 'i', 'l', 'e', 'd', 0,
    's', 'e', 't', 'P', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'N', 'e', 't', 'w', 'o', 'r', 'k', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'P', 'a', 't', 'h', 0,
    'c', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'e', 'x', 't', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'e', 'x', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'A', 't', 0,
    'r', 'e', 'f', 'r', 'e', 's', 'h', 'T', 'o', 'k', 'e', 'n', 0,
    'r', 'e', 'p', 'l', 'y', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'r', 'e', 's', 'p', 'o', 'n', 's', 'e', 'T', 'y', 'p', 'e', 0,
    's', 'c', 'o', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'A', 'g', 'e', 'n', 't', 0,
    's', 't', 'a', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'o', 'k', 'e', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'S', 'e', 'r', 'v', 'e', 'r', 'E', 'r', 'r', 'o', 'r', 0,
    'c', 'o', 'n', 't', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'x', 't', 'r', 'a', 'T', 'o', 'k', 'e', 'n', 's', 0,
    'i', 's', 'L', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 0,
    't', 'o', 'k', 'e', 'n', 'S', 'e', 'c', 'r', 'e', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'H', 'm', 'a', 'c', '_', 'S', 'h', 'a', '1', 0,
    'P', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    'p', 'l', 'a', 'i', 'n', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'u', 's', 0,
    'u', 's', 'e', 'r', 'A', 'g', 'e', 'n', 't', 0,
    'R', 's', 'a', '_', 'S', 'h', 'a', '1', 0,
    'c', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 0,
    'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', 0,
    'h', 'm', 'a', 'c', 'S', 'h', 'a', '1', 0,
    's', 'e', 't', 'S', 'c', 'o', 'p', 'e', 0,
    's', 'e', 't', 'S', 't', 'a', 't', 'e', 0,
    's', 'e', 't', 'T', 'o', 'k', 'e', 'n', 0,
    'G', 'r', 'a', 'n', 't', 'e', 'd', 0,
    'N', 'o', 'E', 'r', 'r', 'o', 'r', 0,
    'Q', 'O', 'A', 'u', 't', 'h', '1', 0,
    'U', 'n', 'k', 'n', 'o', 'w', 'n', 0,
    'a', 'd', 'd', 'r', 'e', 's', 's', 0,
    'g', 'r', 'a', 'n', 't', 'e', 'd', 0,
    'r', 's', 'a', 'S', 'h', 'a', '1', 0,
    'C', 'u', 's', 't', 'o', 'm', 0,
    'D', 'e', 'l', 'e', 't', 'e', 0,
    'i', 'n', 's', 'e', 'r', 't', 0,
    'l', 'i', 's', 't', 'e', 'n', 0,
    'm', 'e', 't', 'h', 'o', 'd', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'U', 'r', 'l', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    'c', 'l', 'o', 's', 'e', 0,
    'e', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'g', 'r', 'a', 'n', 't', 0,
    'n', 'o', 'n', 'c', 'e', 0,
    's', 'c', 'o', 'p', 'e', 0,
    's', 'e', 't', 'u', 'p', 0,
    's', 't', 'a', 't', 'e', 0,
    't', 'o', 'k', 'e', 'n', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'H', 'e', 'a', 'd', 0,
    'J', 's', 'o', 'n', 0,
    'P', 'o', 's', 't', 0,
    'b', 'o', 'd', 'y', 0,
    'h', 'e', 'a', 'd', 0,
    'k', 'e', 'y', 's', 0,
    'p', 'o', 'r', 't', 0,
    'p', 'o', 's', 't', 0,
    's', 'w', 'a', 'p', 0,
    't', 'a', 'k', 'e', 0,
    'G', 'e', 't', 0,
    'P', 'u', 't', 0,
    'g', 'e', 't', 0,
    'p', 'u', 't', 0,
    'u', 'r', 'l', 0,
};
#line 242 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
// Imports from QtCore.
pyqt5_qtnetworkauth_err_print_t pyqt5_qtnetworkauth_err_print;
#line 260 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"

void sipVH_QtNetworkAuth_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QNetworkReply*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QNetworkReply, SIP_NULLPTR);
}

::QString sipVH_QtNetworkAuth_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

::QNetworkReply* sipVH_QtNetworkAuth_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, ::QHttpMultiPart*a1)
{
    ::QNetworkReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "ND", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, a1, sipType_QHttpMultiPart, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QNetworkReply, &sipRes);

    return sipRes;
}

::QNetworkReply* sipVH_QtNetworkAuth_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, const ::QByteArray& a1)
{
    ::QNetworkReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, new ::QByteArray(a1), sipType_QByteArray, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QNetworkReply, &sipRes);

    return sipRes;
}

::QUrl sipVH_QtNetworkAuth_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, const ::QVariantMap& a1)
{
    ::QUrl sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, new ::QVariantMap(a1), sipType_QVariantMap, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QUrl, &sipRes);

    return sipRes;
}

void sipVH_QtNetworkAuth_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, const ::QVariantMap& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "NN", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, new ::QVariantMap(a1), sipType_QVariantMap, SIP_NULLPTR);
}

void sipVH_QtNetworkAuth_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

::QNetworkReply* sipVH_QtNetworkAuth_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QUrl& a0, const ::QVariantMap& a1)
{
    ::QNetworkReply* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "NN", new ::QUrl(a0), sipType_QUrl, SIP_NULLPTR, new ::QVariantMap(a1), sipType_QVariantMap, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QNetworkReply, &sipRes);

    return sipRes;
}

bool sipVH_QtNetworkAuth_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtNetworkAuth_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtNetworkAuth_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_QtNetworkAuth_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtNetworkAuth_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtNetworkAuth_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QAbstractOAuth(void **);}
static const sipTypeDef *sipSubClass_QAbstractOAuth(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 32 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
    static struct class_graph {
        const char *name;
        sipTypeDef **type;
        int yes, no;
    } graph[] = {
        {sipName_QAbstractOAuth, &sipType_QAbstractOAuth, 2, 1},
        {sipName_QAbstractOAuthReplyHandler, &sipType_QAbstractOAuthReplyHandler, 5, -1},
        {sipName_QAbstractOAuth2, &sipType_QAbstractOAuth2, 4, 3},
        {sipName_QOAuth1, &sipType_QOAuth1, -1, -1},
        {sipName_QOAuth2AuthorizationCodeFlow, &sipType_QOAuth2AuthorizationCodeFlow, -1, -1},
        {sipName_QOAuthOobReplyHandler, &sipType_QOAuthOobReplyHandler, 6, -1},
        {sipName_QOAuthHttpServerReplyHandler, &sipType_QOAuthHttpServerReplyHandler, -1, -1},
    };
    
    int i = 0;
    
    sipType = NULL;
    
    do
    {
        struct class_graph *cg = &graph[i];
    
        if (cg->name != NULL && sipCpp->inherits(cg->name))
        {
            sipType = *cg->type;
            i = cg->yes;
        }
        else
            i = cg->no;
    }
    while (i >= 0);
#line 407 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"

    return sipType;
}
static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QAbstractOAuth__ContentType, SIP_NULLPTR, 0}, sipNameNr_ContentType, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QAbstractOAuth__Error, SIP_NULLPTR, 0}, sipNameNr_Error, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QAbstractOAuth__Stage, SIP_NULLPTR, 0}, sipNameNr_Stage, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QAbstractOAuth__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 0, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QOAuth1__SignatureMethod, SIP_NULLPTR, 0}, sipNameNr_SignatureMethod, 8, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_SCOPED_ENUM, sipNameNr_QOAuth1Signature__HttpRequestMethod, SIP_NULLPTR, 0}, sipNameNr_HttpRequestMethod, 10, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtNetworkAuth[] = {
    &sipTypeDef_QtNetworkAuth_QAbstractOAuth.ctd_base,
    &sipTypeDef_QtNetworkAuth_QAbstractOAuth2.ctd_base,
    &enumTypes[0].etd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_QtNetworkAuth_QAbstractOAuthReplyHandler.ctd_base,
    &sipTypeDef_QtNetworkAuth_QList_0100QString.mtd_base,
    &sipTypeDef_QtNetworkAuth_QOAuth1.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtNetworkAuth_QOAuth1Signature.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_QtNetworkAuth_QOAuth2AuthorizationCodeFlow.ctd_base,
    &sipTypeDef_QtNetworkAuth_QOAuthHttpServerReplyHandler.ctd_base,
    &sipTypeDef_QtNetworkAuth_QOAuthOobReplyHandler.ctd_base,
    &sipTypeDef_QtNetworkAuth_QPair_0100QString_0100QString.mtd_base,
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtNetworkAuth_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QDateTime"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QObject"},
    {"QString"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QUrlQuery"},
    {"QVariant"},
    {"QVariantMap"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtNetwork. */
sipImportedTypeDef sipImportedTypes_QtNetworkAuth_QtNetwork[] = {
    {"QHostAddress"},
    {"QHttpMultiPart"},
    {"QNetworkAccessManager"},
    {"QNetworkAccessManager::Operation"},
    {"QNetworkReply"},
    {"QNetworkRequest"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtNetworkAuth_QtCore, sipImportedVirtErrorHandlers_QtNetworkAuth_QtCore, SIP_NULLPTR},
    {"PyQt5.QtNetwork", sipImportedTypes_QtNetworkAuth_QtNetwork, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QAbstractOAuth, {5, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtNetworkAuth = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtNetworkAuth,
    0,
    sipStrings_QtNetworkAuth,
    importsTable,
    SIP_NULLPTR,
    16,
    sipExportedTypes_QtNetworkAuth,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtNetworkAuth;

sip_qt_metaobject_func sip_QtNetworkAuth_qt_metaobject;
sip_qt_metacall_func sip_QtNetworkAuth_qt_metacall;
sip_qt_metacast_func sip_QtNetworkAuth_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtNetworkAuth()
#else
PyMODINIT_FUNC PyInit_QtNetworkAuth()
#endif
{
    static PyMethodDef sip_methods[] = {
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtNetworkAuth",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtNetworkAuth = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtNetworkAuth == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtNetworkAuth, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtNetworkAuth_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtNetworkAuth_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtNetworkAuth_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtNetworkAuth_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtNetworkAuth, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }
#line 247 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
// Imports from QtCore.
pyqt5_qtnetworkauth_err_print = (pyqt5_qtnetworkauth_err_print_t)sipImportSymbol("pyqt5_err_print");
Q_ASSERT(pyqt5_qtnetworkauth_err_print);
#line 619 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthcmodule.cpp"

    return sipModule;
}
