/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtNetworkAuth.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtNetworkAuth.h"

#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
#include <qabstractoauth.h>
#line 29 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 33 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 109 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qurl.sip"
#include <qurl.h>
#line 36 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 24 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvariantmap.sip"
#include <qvariant.h>
#line 39 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 45 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 48 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 28 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauthreplyhandler.sip"
#include <qabstractoauthreplyhandler.h>
#line 51 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 54 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 59 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 62 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 65 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 68 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 71 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 74 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 77 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 80 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 83 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 86 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 89 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 92 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 95 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 98 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 101 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"


PyDoc_STRVAR(doc_QAbstractOAuth_clientIdentifier, "clientIdentifier(self) -> str");

extern "C" {static PyObject *meth_QAbstractOAuth_clientIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_clientIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->clientIdentifier());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_clientIdentifier, doc_QAbstractOAuth_clientIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setClientIdentifier, "setClientIdentifier(self, clientIdentifier: str|None)");

extern "C" {static PyObject *meth_QAbstractOAuth_setClientIdentifier(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setClientIdentifier(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setClientIdentifier(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setClientIdentifier, doc_QAbstractOAuth_setClientIdentifier);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_token, "token(self) -> str");

extern "C" {static PyObject *meth_QAbstractOAuth_token(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_token(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->token());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_token, doc_QAbstractOAuth_token);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setToken, "setToken(self, token: str|None)");

extern "C" {static PyObject *meth_QAbstractOAuth_setToken(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setToken(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setToken(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setToken, doc_QAbstractOAuth_setToken);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_networkAccessManager, "networkAccessManager(self) -> QNetworkAccessManager|None");

extern "C" {static PyObject *meth_QAbstractOAuth_networkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_networkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QNetworkAccessManager*sipRes;

            sipRes = sipCpp->networkAccessManager();

            return sipConvertFromType(sipRes, sipType_QNetworkAccessManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_networkAccessManager, doc_QAbstractOAuth_networkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setNetworkAccessManager, "setNetworkAccessManager(self, networkAccessManager: QNetworkAccessManager|None)");

extern "C" {static PyObject *meth_QAbstractOAuth_setNetworkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setNetworkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNetworkAccessManager* a0;
        PyObject *a0Keep;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QAbstractOAuth, &sipCpp, &a0Keep, sipType_QNetworkAccessManager, &a0))
        {
            sipCpp->setNetworkAccessManager(a0);

            sipKeepReference(sipSelf, -1, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setNetworkAccessManager, doc_QAbstractOAuth_setNetworkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_status, "status(self) -> QAbstractOAuth.Status");

extern "C" {static PyObject *meth_QAbstractOAuth_status(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_status(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QAbstractOAuth::Status sipRes;

            sipRes = sipCpp->status();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractOAuth_Status);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_status, doc_QAbstractOAuth_status);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_authorizationUrl, "authorizationUrl(self) -> QUrl");

extern "C" {static PyObject *meth_QAbstractOAuth_authorizationUrl(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_authorizationUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QUrl*sipRes;

            sipRes = new ::QUrl(sipCpp->authorizationUrl());

            return sipConvertFromNewType(sipRes, sipType_QUrl, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_authorizationUrl, doc_QAbstractOAuth_authorizationUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setAuthorizationUrl, "setAuthorizationUrl(self, url: QUrl)");

extern "C" {static PyObject *meth_QAbstractOAuth_setAuthorizationUrl(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setAuthorizationUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QUrl* a0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0))
        {
            sipCpp->setAuthorizationUrl(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setAuthorizationUrl, doc_QAbstractOAuth_setAuthorizationUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_extraTokens, "extraTokens(self) -> dict[str, Any]");

extern "C" {static PyObject *meth_QAbstractOAuth_extraTokens(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_extraTokens(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QVariantMap*sipRes;

            sipRes = new ::QVariantMap(sipCpp->extraTokens());

            return sipConvertFromNewType(sipRes, sipType_QVariantMap, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_extraTokens, doc_QAbstractOAuth_extraTokens);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_replyHandler, "replyHandler(self) -> QAbstractOAuthReplyHandler|None");

extern "C" {static PyObject *meth_QAbstractOAuth_replyHandler(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_replyHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QAbstractOAuthReplyHandler*sipRes;

            sipRes = sipCpp->replyHandler();

            return sipConvertFromType(sipRes, sipType_QAbstractOAuthReplyHandler, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_replyHandler, doc_QAbstractOAuth_replyHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setReplyHandler, "setReplyHandler(self, handler: QAbstractOAuthReplyHandler|None)");

extern "C" {static PyObject *meth_QAbstractOAuth_setReplyHandler(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setReplyHandler(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractOAuthReplyHandler* a0;
        PyObject *a0Keep;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QAbstractOAuth, &sipCpp, &a0Keep, sipType_QAbstractOAuthReplyHandler, &a0))
        {
            sipCpp->setReplyHandler(a0);

            sipKeepReference(sipSelf, -2, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setReplyHandler, doc_QAbstractOAuth_setReplyHandler);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_head, "head(self, url: QUrl, parameters: dict[str, Any] = {}) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QAbstractOAuth_head(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_head(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_head);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->head(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_head, doc_QAbstractOAuth_head);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_get, "get(self, url: QUrl, parameters: dict[str, Any] = {}) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QAbstractOAuth_get(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_get(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_get);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->get(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_get, doc_QAbstractOAuth_get);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_post, "post(self, url: QUrl, parameters: dict[str, Any] = {}) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QAbstractOAuth_post(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_post(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_post);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->post(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_post, doc_QAbstractOAuth_post);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_put, "put(self, url: QUrl, parameters: dict[str, Any] = {}) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QAbstractOAuth_put(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_put(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_put);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->put(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_put, doc_QAbstractOAuth_put);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_deleteResource, "deleteResource(self, url: QUrl, parameters: dict[str, Any] = {}) -> QNetworkReply|None");

extern "C" {static PyObject *meth_QAbstractOAuth_deleteResource(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_deleteResource(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        const ::QUrl* a0;
        const ::QVariantMap& a1def = QVariantMap();
        const ::QVariantMap* a1 = &a1def;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parameters,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ9|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            ::QNetworkReply*sipRes;

            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_deleteResource);
                return SIP_NULLPTR;
            }

            sipRes = sipCpp->deleteResource(*a0, *a1);
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            return sipConvertFromType(sipRes, sipType_QNetworkReply, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_deleteResource, doc_QAbstractOAuth_deleteResource);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_modifyParametersFunction, "modifyParametersFunction(self) -> Callable[..., None]");

extern "C" {static PyObject *meth_QAbstractOAuth_modifyParametersFunction(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_modifyParametersFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            PyObject * sipRes = SIP_NULLPTR;

#line 118 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
        // The callable, if any, is held in the user object.
        sipRes = sipGetUserObject((sipSimpleWrapper *)sipSelf);
        
        if (!sipRes)
            sipRes = Py_None;
        
        Py_INCREF(sipRes);
#line 663 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"

            return sipRes;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_modifyParametersFunction, doc_QAbstractOAuth_modifyParametersFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setModifyParametersFunction, "setModifyParametersFunction(self, modifyParametersFunction: Callable[..., None])");

extern "C" {static PyObject *meth_QAbstractOAuth_setModifyParametersFunction(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setModifyParametersFunction(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        PyObject * a0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BH", &sipSelf, sipType_QAbstractOAuth, &sipCpp, &a0))
        {
#line 129 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/sip/QtNetworkAuth/qabstractoauth.sip"
        // Remove any existing callable.
        PyObject *func = sipGetUserObject((sipSimpleWrapper *)sipSelf);
        Py_XDECREF(func);
        
        // Save the new callable.
        if (a0 == Py_None)
        {
            func = 0;
        }
        else
        {
            func = a0;
            Py_INCREF(func);
        }
        
        sipSetUserObject((sipSimpleWrapper *)sipSelf, func);
        
        Py_BEGIN_ALLOW_THREADS
        
        sipCpp->setModifyParametersFunction([func](QAbstractOAuth::Stage stage, QVariantMap *parameters) {
            if (func)
            {
                SIP_BLOCK_THREADS
        
                static const sipTypeDef *variant_map = 0;
        
                if (!variant_map)
                {
                    variant_map = sipFindType("QVariantMap");
                    Q_ASSERT(variant_map);
                }
        
                PyObject *parameters_obj = sipConvertFromType(parameters, variant_map, NULL);
        
                if (!parameters_obj)
                {
                    pyqt5_qtnetworkauth_err_print();
                }
                else
                {
                    PyObject *res = sipCallMethod(NULL, func, "FS", stage, sipType_QAbstractOAuth_Stage, parameters_obj);
        
                    if (!res)
                    {
                        pyqt5_qtnetworkauth_err_print();
                    }
                    else
                    {
                        Py_DECREF(res);
        
                        int iserr = 0;
                        QVariantMap *updated = reinterpret_cast<QVariantMap *>(sipForceConvertToType(parameters_obj, variant_map, NULL, SIP_NO_CONVERTORS, NULL, &iserr));
        
                        if (iserr)
                        {
                            pyqt5_qtnetworkauth_err_print();
                        }
                        else
                        {
                            // Copy the updated parameters.
                            *parameters = *updated;
                            delete updated;
                        }
                    }
        
                    Py_DECREF(parameters_obj);
                }
        
                SIP_UNBLOCK_THREADS
            }
        });
        
        Py_END_ALLOW_THREADS
#line 762 "/build/python-pyqt5-networkauth/src/PyQtNetworkAuth-5.15.6/build/QtNetworkAuth/sipQtNetworkAuthQAbstractOAuth.cpp"

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setModifyParametersFunction, doc_QAbstractOAuth_setModifyParametersFunction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_contentType, "contentType(self) -> QAbstractOAuth.ContentType");

extern "C" {static PyObject *meth_QAbstractOAuth_contentType(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_contentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QAbstractOAuth::ContentType sipRes;

            sipRes = sipCpp->contentType();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QAbstractOAuth_ContentType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_contentType, doc_QAbstractOAuth_contentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setContentType, "setContentType(self, contentType: QAbstractOAuth.ContentType)");

extern "C" {static PyObject *meth_QAbstractOAuth_setContentType(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setContentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractOAuth::ContentType a0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QAbstractOAuth_ContentType, &a0))
        {
            sipCpp->setContentType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setContentType, doc_QAbstractOAuth_setContentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_prepareRequest, "prepareRequest(self, request: QNetworkRequest|None, verb: QByteArray|bytes|bytearray, body: QByteArray|bytes|bytearray = QByteArray())");

extern "C" {static PyObject *meth_QAbstractOAuth_prepareRequest(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_prepareRequest(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNetworkRequest* a0;
        const ::QByteArray* a1;
        int a1State = 0;
        const ::QByteArray& a2def = QByteArray();
        const ::QByteArray* a2 = &a2def;
        int a2State = 0;
        ::QAbstractOAuth *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_body,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ8J1|J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QNetworkRequest, &a0, sipType_QByteArray, &a1, &a1State, sipType_QByteArray, &a2, &a2State))
        {
            sipCpp->prepareRequest(a0, *a1, *a2);
            sipReleaseType(const_cast< ::QByteArray *>(a1), sipType_QByteArray, a1State);
            sipReleaseType(const_cast< ::QByteArray *>(a2), sipType_QByteArray, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_prepareRequest, doc_QAbstractOAuth_prepareRequest);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_grant, "grant(self)");

extern "C" {static PyObject *meth_QAbstractOAuth_grant(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_grant(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    PyObject *sipOrigSelf = sipSelf;

    {
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            if (!sipOrigSelf)
            {
                sipAbstractMethod(sipName_QAbstractOAuth, sipName_grant);
                return SIP_NULLPTR;
            }

            sipCpp->grant();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_grant, doc_QAbstractOAuth_grant);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_setStatus, "setStatus(self, status: QAbstractOAuth.Status)");

extern "C" {static PyObject *meth_QAbstractOAuth_setStatus(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_setStatus(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QAbstractOAuth::Status a0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QAbstractOAuth_Status, &a0))
        {
            sipCpp->setStatus(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_setStatus, doc_QAbstractOAuth_setStatus);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_callback, "callback(self) -> str");

extern "C" {static PyObject *meth_QAbstractOAuth_callback(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_callback(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QAbstractOAuth, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->callback());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_callback, doc_QAbstractOAuth_callback);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_resourceOwnerAuthorization, "resourceOwnerAuthorization(self, url: QUrl, parameters: dict[str, Any])");

extern "C" {static PyObject *meth_QAbstractOAuth_resourceOwnerAuthorization(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_resourceOwnerAuthorization(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QUrl* a0;
        const ::QVariantMap* a1;
        int a1State = 0;
        ::QAbstractOAuth *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9J1", &sipSelf, sipType_QAbstractOAuth, &sipCpp, sipType_QUrl, &a0, sipType_QVariantMap, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QAbstractOAuth::resourceOwnerAuthorization(*a0, *a1) : sipCpp->resourceOwnerAuthorization(*a0, *a1));
            sipReleaseType(const_cast< ::QVariantMap *>(a1), sipType_QVariantMap, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_resourceOwnerAuthorization, doc_QAbstractOAuth_resourceOwnerAuthorization);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QAbstractOAuth_generateRandomString, "generateRandomString(length: int) -> QByteArray");

extern "C" {static PyObject *meth_QAbstractOAuth_generateRandomString(PyObject *, PyObject *);}
static PyObject *meth_QAbstractOAuth_generateRandomString(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::quint8 a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "M", &a0))
        {
            ::QByteArray*sipRes;

            sipRes = new ::QByteArray(::QAbstractOAuth::generateRandomString(a0));

            return sipConvertFromNewType(sipRes, sipType_QByteArray, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstractOAuth, sipName_generateRandomString, doc_QAbstractOAuth_generateRandomString);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QAbstractOAuth(void *, const sipTypeDef *);}
static void *cast_QAbstractOAuth(void *sipCppV, const sipTypeDef *targetType)
{
    ::QAbstractOAuth *sipCpp = reinterpret_cast< ::QAbstractOAuth *>(sipCppV);

    if (targetType == sipType_QAbstractOAuth)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QAbstractOAuth(void *, int);}
static void release_QAbstractOAuth(void *sipCppV, int)
{
    ::QAbstractOAuth *sipCpp = reinterpret_cast< ::QAbstractOAuth *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QAbstractOAuth(sipSimpleWrapper *);}
static void dealloc_QAbstractOAuth(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QAbstractOAuth(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QAbstractOAuth[] = {{5, 0, 1}};


static PyMethodDef methods_QAbstractOAuth[] = {
    {sipName_authorizationUrl, meth_QAbstractOAuth_authorizationUrl, METH_VARARGS, doc_QAbstractOAuth_authorizationUrl},
    {sipName_callback, meth_QAbstractOAuth_callback, METH_VARARGS, doc_QAbstractOAuth_callback},
    {sipName_clientIdentifier, meth_QAbstractOAuth_clientIdentifier, METH_VARARGS, doc_QAbstractOAuth_clientIdentifier},
    {sipName_contentType, meth_QAbstractOAuth_contentType, METH_VARARGS, doc_QAbstractOAuth_contentType},
    {sipName_deleteResource, SIP_MLMETH_CAST(meth_QAbstractOAuth_deleteResource), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_deleteResource},
    {sipName_extraTokens, meth_QAbstractOAuth_extraTokens, METH_VARARGS, doc_QAbstractOAuth_extraTokens},
    {sipName_generateRandomString, meth_QAbstractOAuth_generateRandomString, METH_VARARGS, doc_QAbstractOAuth_generateRandomString},
    {sipName_get, SIP_MLMETH_CAST(meth_QAbstractOAuth_get), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_get},
    {sipName_grant, meth_QAbstractOAuth_grant, METH_VARARGS, doc_QAbstractOAuth_grant},
    {sipName_head, SIP_MLMETH_CAST(meth_QAbstractOAuth_head), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_head},
    {sipName_modifyParametersFunction, meth_QAbstractOAuth_modifyParametersFunction, METH_VARARGS, doc_QAbstractOAuth_modifyParametersFunction},
    {sipName_networkAccessManager, meth_QAbstractOAuth_networkAccessManager, METH_VARARGS, doc_QAbstractOAuth_networkAccessManager},
    {sipName_post, SIP_MLMETH_CAST(meth_QAbstractOAuth_post), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_post},
    {sipName_prepareRequest, SIP_MLMETH_CAST(meth_QAbstractOAuth_prepareRequest), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_prepareRequest},
    {sipName_put, SIP_MLMETH_CAST(meth_QAbstractOAuth_put), METH_VARARGS|METH_KEYWORDS, doc_QAbstractOAuth_put},
    {sipName_replyHandler, meth_QAbstractOAuth_replyHandler, METH_VARARGS, doc_QAbstractOAuth_replyHandler},
    {sipName_resourceOwnerAuthorization, meth_QAbstractOAuth_resourceOwnerAuthorization, METH_VARARGS, doc_QAbstractOAuth_resourceOwnerAuthorization},
    {sipName_setAuthorizationUrl, meth_QAbstractOAuth_setAuthorizationUrl, METH_VARARGS, doc_QAbstractOAuth_setAuthorizationUrl},
    {sipName_setClientIdentifier, meth_QAbstractOAuth_setClientIdentifier, METH_VARARGS, doc_QAbstractOAuth_setClientIdentifier},
    {sipName_setContentType, meth_QAbstractOAuth_setContentType, METH_VARARGS, doc_QAbstractOAuth_setContentType},
    {sipName_setModifyParametersFunction, meth_QAbstractOAuth_setModifyParametersFunction, METH_VARARGS, doc_QAbstractOAuth_setModifyParametersFunction},
    {sipName_setNetworkAccessManager, meth_QAbstractOAuth_setNetworkAccessManager, METH_VARARGS, doc_QAbstractOAuth_setNetworkAccessManager},
    {sipName_setReplyHandler, meth_QAbstractOAuth_setReplyHandler, METH_VARARGS, doc_QAbstractOAuth_setReplyHandler},
    {sipName_setStatus, meth_QAbstractOAuth_setStatus, METH_VARARGS, doc_QAbstractOAuth_setStatus},
    {sipName_setToken, meth_QAbstractOAuth_setToken, METH_VARARGS, doc_QAbstractOAuth_setToken},
    {sipName_status, meth_QAbstractOAuth_status, METH_VARARGS, doc_QAbstractOAuth_status},
    {sipName_token, meth_QAbstractOAuth_token, METH_VARARGS, doc_QAbstractOAuth_token}
};

static sipEnumMemberDef enummembers_QAbstractOAuth[] = {
    {sipName_Granted, static_cast<int>(::QAbstractOAuth::Status::Granted), 5},
    {sipName_Json, static_cast<int>(::QAbstractOAuth::ContentType::Json), 2},
    {sipName_NetworkError, static_cast<int>(::QAbstractOAuth::Error::NetworkError), 3},
    {sipName_NoError, static_cast<int>(::QAbstractOAuth::Error::NoError), 3},
    {sipName_NotAuthenticated, static_cast<int>(::QAbstractOAuth::Status::NotAuthenticated), 5},
    {sipName_OAuthCallbackNotVerified, static_cast<int>(::QAbstractOAuth::Error::OAuthCallbackNotVerified), 3},
    {sipName_OAuthTokenNotFoundError, static_cast<int>(::QAbstractOAuth::Error::OAuthTokenNotFoundError), 3},
    {sipName_OAuthTokenSecretNotFoundError, static_cast<int>(::QAbstractOAuth::Error::OAuthTokenSecretNotFoundError), 3},
    {sipName_RefreshingAccessToken, static_cast<int>(::QAbstractOAuth::Stage::RefreshingAccessToken), 4},
    {sipName_RefreshingToken, static_cast<int>(::QAbstractOAuth::Status::RefreshingToken), 5},
    {sipName_RequestingAccessToken, static_cast<int>(::QAbstractOAuth::Stage::RequestingAccessToken), 4},
    {sipName_RequestingAuthorization, static_cast<int>(::QAbstractOAuth::Stage::RequestingAuthorization), 4},
    {sipName_RequestingTemporaryCredentials, static_cast<int>(::QAbstractOAuth::Stage::RequestingTemporaryCredentials), 4},
    {sipName_ServerError, static_cast<int>(::QAbstractOAuth::Error::ServerError), 3},
    {sipName_TemporaryCredentialsReceived, static_cast<int>(::QAbstractOAuth::Status::TemporaryCredentialsReceived), 5},
    {sipName_WwwFormUrlEncoded, static_cast<int>(::QAbstractOAuth::ContentType::WwwFormUrlEncoded), 2},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QAbstractOAuth[] = {
    {"replyDataReceived(QByteArray)", "\1replyDataReceived(self, data: QByteArray|bytes|bytearray)", SIP_NULLPTR, SIP_NULLPTR},
    {"finished(QNetworkReply*)", "\1finished(self, reply: QNetworkReply|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"granted()", "\1granted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"authorizeWithBrowser(QUrl)", "\1authorizeWithBrowser(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"requestFailed(Error)|(QAbstractOAuth::Error)", "\1requestFailed(self, error: QAbstractOAuth.Error)", SIP_NULLPTR, SIP_NULLPTR},
    {"contentTypeChanged(ContentType)|(QAbstractOAuth::ContentType)", "\1contentTypeChanged(self, contentType: QAbstractOAuth.ContentType)", SIP_NULLPTR, SIP_NULLPTR},
    {"extraTokensChanged(QVariantMap)", "\1extraTokensChanged(self, tokens: dict[str, Any])", SIP_NULLPTR, SIP_NULLPTR},
    {"authorizationUrlChanged(QUrl)", "\1authorizationUrlChanged(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusChanged(Status)|(QAbstractOAuth::Status)", "\1statusChanged(self, status: QAbstractOAuth.Status)", SIP_NULLPTR, SIP_NULLPTR},
    {"tokenChanged(QString)", "\1tokenChanged(self, token: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"clientIdentifierChanged(QString)", "\1clientIdentifierChanged(self, clientIdentifier: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QAbstractOAuth = {
    &::QAbstractOAuth::staticMetaObject,
    0,
    signals_QAbstractOAuth,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtNetworkAuth_QAbstractOAuth = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_ABSTRACT|SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QAbstractOAuth,
        SIP_NULLPTR,
        &plugin_QAbstractOAuth,
    },
    {
        sipNameNr_QAbstractOAuth,
        {0, 0, 1},
        27, methods_QAbstractOAuth,
        16, enummembers_QAbstractOAuth,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QAbstractOAuth,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QAbstractOAuth,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QAbstractOAuth,
    cast_QAbstractOAuth,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
